@@ -6,5 +6,6 @@ var searchData=
   ['how_20do_20i_20swap_20some_20keys_3',['How do I swap some keys?',['../faq.html#how-do-i-swap-some-keys',1,'']]],
   ['how_20do_20i_20test_20my_20custom_20layout_20without_20installing_20it_4',['How do I test my custom layout without installing it?',['../faq.html#how-do-i-test-my-custom-layout-without-installing-it',1,'']]],
   ['how_20key_20types_20work_5',['How key types work',['../keymap-text-format-v1-v2.html#how-key-types-work',1,'']]],
-  ['how_20to_20get_20the_20virtual_20to_20real_20modifiers_20mappings_6',['How to get the virtual to real modifiers mappings?',['../faq.html#how-to-get-the-virtual-to-real-modifiers-mappings',1,'']]]
+  ['how_20to_20get_20the_20keys_20that_20trigger_20modifiers_6',['How to get the keys that trigger modifiers?',['../faq.html#how-to-get-the-keys-that-trigger-modifiers',1,'']]],
+  ['how_20to_20get_20the_20virtual_20modifier_20encoding_7',['How to get the virtual modifier encoding?',['../faq.html#how-to-get-the-virtual-modifier-encoding',1,'']]]
 ];
