@@ -8,11 +8,11 @@ var searchData=
   ['variant_5',['variant',['../structxkb__rule__names.html#a758e1865c002d8f4fb59b2e3dda83b66',1,'xkb_rule_names']]],
   ['variants_20and_20symbols_6',['Example: layouts, variants and symbols',['../rule-file-format.html#rules-symbols-example',1,'']]],
   ['virtual_20modifier_7',['XKB-123 – Undeclared virtual modifier',['../error-index.html#XKB-123',1,'']]],
-  ['virtual_20modifier_20map_8',['Setting the virtual modifier map',['../keymap-text-format-v1-v2.html#set-virtual-mod-map',1,'']]],
-  ['virtual_20modifier_20names_9',['Legacy virtual modifier names',['../group__legacy-virtual-modifier-names.html',1,'']]],
-  ['virtual_20modifiers_10',['Virtual modifiers',['../keymap-text-format-v1-v2.html#key-virtual-modifiers',1,'']]],
-  ['virtual_20modifiers_11',['Real and virtual modifiers',['../keymap-text-format-v1-v2.html#real-and-virtual-modifiers',1,'']]],
-  ['virtual_20modifiers_20names_12',['Virtual modifiers names',['../group__virtual-modifier-names.html',1,'']]],
-  ['virtual_20to_20real_20modifiers_20mappings_13',['How to get the virtual to real modifiers mappings?',['../faq.html#how-to-get-the-virtual-to-real-modifiers-mappings',1,'']]],
+  ['virtual_20modifier_20encoding_8',['How to get the virtual modifier encoding?',['../faq.html#how-to-get-the-virtual-modifier-encoding',1,'']]],
+  ['virtual_20modifier_20map_9',['Setting the virtual modifier map',['../keymap-text-format-v1-v2.html#set-virtual-mod-map',1,'']]],
+  ['virtual_20modifier_20names_10',['Legacy virtual modifier names',['../group__legacy-virtual-modifier-names.html',1,'']]],
+  ['virtual_20modifiers_11',['Virtual modifiers',['../keymap-text-format-v1-v2.html#key-virtual-modifiers',1,'']]],
+  ['virtual_20modifiers_12',['Real and virtual modifiers',['../keymap-text-format-v1-v2.html#real-and-virtual-modifiers',1,'']]],
+  ['virtual_20modifiers_20names_13',['Virtual modifiers names',['../group__virtual-modifier-names.html',1,'']]],
   ['vs_20kccgst_14',['RMLVO vs KcCGST',['../user-configuration.html#rmlvo-vs-kccgst',1,'']]]
 ];
